@@ -1,9 +1,10 @@
+
 ic.ccc <-
 function(ccc,dev,S,alpha){
   
 se.ccc <- sqrt(dev%*%S%*%t(dev))
 z<-0.5*log((1+ccc)/(1-ccc))
-se.z<-sqrt(  (se.ccc^2)/(((1+ccc)^2)*((1-ccc)^2))  )
+se.z<-c(sqrt(  (se.ccc^2)/(((1+ccc)^2)*((1-ccc)^2))  ) )
 ic.z=z+c(-1,1)*qnorm(1-alpha/2)*se.z
 ic.icc=(exp(2*ic.z)-1)/(exp(2*ic.z)+1)
 result<-c(ccc,ic.icc,se.ccc,z,se.z)
